SingleTabbedDataset
===================

.. currentmodule:: pykeen.datasets.base

.. autoclass:: SingleTabbedDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SingleTabbedDataset.ratios

   .. rubric:: Attributes Documentation

   .. autoattribute:: ratios
